@@ -3,6 +3,7 @@ from libqtile.config import Key
 from libqtile.utils import guess_terminal
 from stonecharioteer.qtile.inputs import Keyboard, MOD
 
+
 def configure_keymaps(groups):
     """Configures keymaps"""
     terminal = "/bin/konsole"
@@ -75,7 +76,7 @@ def configure_keymaps(groups):
         Key(
             MODIFIER_SET_1,
             "r",
-            lazy.spawncmd(),
+            lazy.spawn("""rofi -modi "drun,run,window,ssh" -show drun"""),
             desc="Spawn a command using a prompt widget",
         ),
     ]
@@ -105,17 +106,11 @@ def configure_keymaps(groups):
         )
     # WIP: shift focus to monitor / screen
     display_keys = ["u", "i", "y"]
-     
+
     try:
         for ix, key in enumerate(display_keys):
-            keys.append(
-                    Key(
-                        MODIFIER_SET_1,
-                        key,
-                        lazy.to_screen(ix)
-                        )
-                    )
+            keys.append(Key(MODIFIER_SET_1, key, lazy.to_screen(ix)))
     except:
         pass
-        
+
     return keys
